@@ -36,7 +36,7 @@ LearnerRegrRpart = R6Class("LearnerRegrRpart", inherit = LearnerRegr,
 
       super$initialize(
         id = "regr.rpart",
-        feature_types = c("logical", "integer", "numeric", "character", "factor", "ordered"),
+        feature_types = c("logical", "integer", "numeric", "factor", "ordered"),
         predict_types = "response",
         packages = "rpart",
         param_set = ps,
