@@ -34,6 +34,12 @@
 #'   `integer()` -> `integer()`\cr
 #'   Translates iteration numbers to repetition number.
 #'
+#' @section Parameters:
+#' * `repeats` :: `integer(1)`\cr
+#'   Number of repetitions.
+#' * `folds` :: `integer(1)`\cr
+#'   Number of folds.
+#'
 #' @template seealso_resampling
 #' @export
 #' @examples
@@ -59,12 +65,11 @@ ResamplingRepeatedCV = R6Class("ResamplingRepeatedCV", inherit = Resampling,
   public = list(
     initialize = function() {
       ps = ParamSet$new(list(
-        ParamUty$new("stratify", default = NULL),
         ParamInt$new("repeats", lower = 1),
         ParamInt$new("folds", lower = 1L, tags = "required")
       ))
       ps$values = list(repeats = 10L, folds = 10L)
-      super$initialize(id = "repeated_cv", param_set = ps)
+      super$initialize(id = "repeated_cv", param_set = ps, man = "mlr3::mlr_resamplings_repeated_cv")
     },
 
     folds = function(iters) {
